%bcond_without docs
%bcond_without tests

# Set xc_host to ecl (a bit faster) or clisp
%define _xc_host ecl

# disable simd on x86_64 (requires avx2 detection on building host)
%bcond_with avx2

%define sbcl_shell /bin/bash

%ifarch %{ix86}
%define sbcl_arch x86
%endif

%ifarch x86_64
%define sbcl_arch x86-64
%endif

%ifarch %{arm}
%define sbcl_arch arm
%endif

%ifarch aarch64
%define sbcl_arch arm64
%endif

Name:           sbcl
Version:        2.5.5
Release:        %mkrel 1
Summary:        Steel Bank Common Lisp compiler and runtime system
License:        Public Domain and MIT and BSD with advertising
Group:          Development/Other
URL:            https://sbcl.sourceforge.net/
Source0:        https://downloads.sourceforge.net/sbcl/sbcl-%{version}-source.tar.bz2
Source1:        https://downloads.sourceforge.net/sbcl/sbcl-%{version}-documentation-html.tar.bz2
Patch2:         sbcl-1.4.12-personality.patch
Patch6:         sbcl-2.0.10-arm.patch
# From https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=931795
Patch7:         sbcl-2.2.10-armv7.patch
Patch8:         sbcl-2.2.10-fix-o_largefile.patch

## upstreamable patches
Patch50:        sbcl-2.0.1-generate_version.patch

# from gentoo
# modified from https://bugs.gentoo.org/468482
Patch100:       concurrency-test-2.2.10.patch
Patch101:       sb-posix-test-2.2.10.patch
Patch102:       bsd-sockets-test-2.2.10.patch
Patch103:       verbose-build-2.2.10.patch

#Patch200:	sbcl-git-20221119-upstream-coalesced.patch
#
Patch202:       sbcl-2.2.10-optflags.patch
Patch203:       sbcl-2.2.10-increase-control-stack-size.patch

BuildRequires: %{_xc_host}
BuildRequires: pkgconfig(atomic_ops)
BuildRequires: pkgconfig(libzstd)
BuildRequires: pkgconfig(zlib)
%if %{with tets}
BuildRequires: ed
BuildRequires: hostname
BuildRequires: procps-ng
BuildRequires: strace
%endif
%if %{with docs}
BuildRequires: ghostscript
BuildRequires: texinfo
BuildRequires: time
%endif
%if %{without bootstrap}
BuildRequires: %{name}
%endif

%description
Steel Bank Common Lisp (SBCL) is a Open Source development environment for
Common Lisp. It includes an integrated native compiler, interpreter, and
debugger.


%prep
%autosetup -p1 %{?bootstrap_src} -a 1

# fix permissions (some have eXecute bit set)
find . -name '*.c' | xargs chmod 644

# set version.lisp-expr
sed -i.rpmver -e "s|\"%{version}\"|\"%{version}-%{release}\"|" version.lisp-expr

%build
export CFLAGS+=" -D_LARGEFILE_SOURCE -D_LARGEFILE64_SOURCE -D_FILE_OFFSET_BITS=64"
export LINKFLAGS="%ldflags"
%{?sbcl_arch:
export SBCL_ARCH=%{sbcl_arch} }

%{?sbcl_shell} \
./make.sh \
  --prefix=%{_prefix} \
  --fancy \
%if %without avx2
  --without-sb-simd \
%else
  --with-sb-simd \
%endif
  --with-sb-core-compression \
  --without-sb-test \
  --xc-host=%{_xc_host}

# docs
%if %{with docs}
make -C doc/manual info

# Handle pre-generated docs
tar xvjf %{SOURCE1}
cp -av %{name}-%{version}/doc/manual/* doc/manual/
%endif

%install
export INSTALL_ROOT=%{buildroot}%{_prefix}
export LIB_DIR=%{buildroot}%{_libdir}
%{?sbcl_shell} ./install.sh

# handle docs in files section
rm -rf %{buildroot}%{_docdir}

# 'test-passed' files from %%check
find %{buildroot} -name 'test-passed' | xargs rm -vf

%if %{with tests}
%check
cd tests
export TEST_SBCL_HOME=%{buildroot}%{_prefix}/lib/sbcl
export TEST_SBCL_RUNTIME=%{buildroot}%{_bindir}/sbcl
export TEST_SBCL_CORE=%{buildroot}%{_prefix}/lib/sbcl/sbcl.core
export ASDF_OUTPUT_TRANSLATIONS="/:${AUTOPKGTEST_TMP}"
export C_INCLUDE_PATH=%{buildroot}%{_datadir}/sbcl-source/src/runtime/
./run-tests.sh
%endif

%files
%license COPYING
%doc BUGS CREDITS NEWS
%{_bindir}/*
%dir %{_prefix}/lib/%{name}/
%{_prefix}/lib/%{name}/sbcl.core
%{_prefix}/lib/%{name}/sbcl.mk
%dir %{_prefix}/lib/%{name}/contrib
%{_prefix}/lib/%{name}/contrib/asdf.*
%{_prefix}/lib/%{name}/contrib/sb-aclrepl.*
%{_prefix}/lib/%{name}/contrib/sb-bsd-sockets.*
%{_prefix}/lib/%{name}/contrib/sb-capstone.*
%{_prefix}/lib/%{name}/contrib/sb-cltl2.*
%{_prefix}/lib/%{name}/contrib/sb-concurrency.*
%{_prefix}/lib/%{name}/contrib/sb-cover.*
%{_prefix}/lib/%{name}/contrib/sb-executable.*
%{_prefix}/lib/%{name}/contrib/sb-gmp.*
%{_prefix}/lib/%{name}/contrib/sb-grovel.*
%{_prefix}/lib/%{name}/contrib/sb-introspect.*
%{_prefix}/lib/%{name}/contrib/sb-md5.*
%{_prefix}/lib/%{name}/contrib/sb-mpfr.*
%{_prefix}/lib/%{name}/contrib/sb-perf.*
%{_prefix}/lib/%{name}/contrib/sb-posix.*
%{_prefix}/lib/%{name}/contrib/sb-queue.*
%{_prefix}/lib/%{name}/contrib/sb-rotate-byte.*
%{_prefix}/lib/%{name}/contrib/sb-rt.*
%ifarch x86_64
%if %with avx2
%{_prefix}/lib/%{name}/contrib/sb-simd.asd
%{_prefix}/lib/%{name}/contrib/sb-simd.fasl
%endif
%endif
%{_prefix}/lib/%{name}/contrib/sb-simple-streams.*
%{_prefix}/lib/%{name}/contrib/sb-sprof.*
%{_prefix}/lib/%{name}/contrib/uiop.*
%{_mandir}/man?/*
%if %{with docs}
%doc doc/manual/sbcl.html
%doc doc/manual/asdf.html
%{_infodir}/asdf.info*
%{_infodir}/sbcl.info*
%endif


%changelog
* Sat Jun 07 2025 daviddavid <daviddavid> 2.5.5-1.mga10
+ Revision: 2189575
- new version: 2.5.5
- rediff patches (bsd-sockets-test,sb-posix-test,arm,optflags,verbose-build)
- remove bootstraping, use ecl(clisp) to build sbcl
- add check section
  * (thanks to Aurelian R)

* Mon Nov 21 2022 ghibo <ghibo> 2.2.10-1.mga9
+ Revision: 1909684
- Disable simd (avx2) on x86_64
- Build with bundled make-4.3.
- Enable simd on x86_64.
- increase default control stack size to 32MB.
- build on armv7hl as -march=armv7-a and not as -march=armv5t
- merge git upstream patches.
- let simd (avx2) support be conditional
- Update to release 2.2.10.
- Remove already unused patches (1,3,4,5).
- Add Patch7 to fix failing compilation.
- Merge Patch100-103 from gentoo.
- Fix file list.
- Add libzstd to BuildRequires.

* Tue Mar 29 2022 umeabot <umeabot> 2.1.7-2.mga9
+ Revision: 1831592
- Mageia 9 Mass Rebuild

* Tue Aug 03 2021 luigiwalser <luigiwalser> 2.1.7-1.mga9
+ Revision: 1738801
- 2.1.7

* Sun Nov 01 2020 joequant <joequant> 2.0.10-4.mga8
+ Revision: 1641156
- revert march fix

* Sun Nov 01 2020 joequant <joequant> 2.0.10-3.mga8
+ Revision: 1641151
- run with armv7 arch

* Sun Nov 01 2020 joequant <joequant> 2.0.10-2.mga8
+ Revision: 1641143
- fix arm build

* Sun Nov 01 2020 joequant <joequant> 2.0.10-1.mga8
+ Revision: 1641138
- update to 2.0.10 and fix build

* Sun Feb 16 2020 wally <wally> 2.0.1-1.mga8
+ Revision: 1533909
- new version 2.0.1

* Fri Feb 14 2020 umeabot <umeabot> 1.4.12-4.mga8
+ Revision: 1519438
- Mageia 8 Mass Rebuild

* Sun Oct 14 2018 wally <wally> 1.4.12-3.mga7
+ Revision: 1320251
- disable bootstrap build on arm

* Sun Oct 14 2018 wally <wally> 1.4.12-2.mga7
+ Revision: 1320246
- disable bootstrap build on aarch64
- bootstrap using static binaries from upstream

* Sun Oct 14 2018 wally <wally> 1.4.12-1.mga7
+ Revision: 1320212
- new version 1.4.12
- enable bootstrap build on arm and aarch64
- sync a bit with Fedora
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon Apr 23 2018 kekepower <kekepower> 1.4.6-2.mga7
+ Revision: 1221367
- Non bootstrap build

* Sun Apr 22 2018 kekepower <kekepower> 1.4.6-1.mga7
+ Revision: 1221251
- Update to version 1.4.6
- Rediffed patches

* Fri Oct 21 2016 daviddavid <daviddavid> 1.1.14-5.mga6
+ Revision: 1062892
- disable Postscript and pdf documentation as they fails to build

* Fri Feb 05 2016 umeabot <umeabot> 1.1.14-4.mga6
+ Revision: 938471
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.1.14-3.mga5
+ Revision: 741393
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.1.14-2.mga5
+ Revision: 689043
- Mageia 5 Mass Rebuild

* Tue Jan 21 2014 shlomif <shlomif> 1.1.14-1.mga4
+ Revision: 567357
- Upgraded to 1.1.14.
  The patches were updated in the process.
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sun Jun 02 2013 kamil <kamil> 1.1.8-1.mga4
+ Revision: 435455
- new version 1.1.8
- drop P10 problem resolved upstream

* Sat Feb 02 2013 kamil <kamil> 1.1.4-1.mga3
+ Revision: 394168
- new version 1.1.4
- add P10 fdr-fix-build-with-new-glibc.patch and fix build

* Sat Dec 01 2012 kamil <kamil> 1.1.2-2.mga3
+ Revision: 324310
- rediff P3
- new version 1.1.2

* Sat Dec 01 2012 kamil <kamil> 1.0.57-2.mga3
+ Revision: 324300
- add new BR: texinfo-tex

* Mon May 28 2012 kamil <kamil> 1.0.57-1.mga3
+ Revision: 247686
- new version 1.0.57

* Fri Jan 13 2012 kamil <kamil> 1.0.55-3.mga2
+ Revision: 195490
- fix license

* Thu Jan 12 2012 kamil <kamil> 1.0.55-2.mga2
+ Revision: 195363
- disable bootstrap building

* Thu Jan 12 2012 kamil <kamil> 1.0.55-1.mga2
+ Revision: 195331
- re-include old patches and rediff them
- drop ppc and sparc patching against %%optflags in optflags.patch
- re-include customize-target-features script
- reeanble and use again old variables:
  o SBCL_HOME
  o DEFAULT_SBCL_HOME
  o RPM_OPT_FLAGS
  o LIB_DIR
- fix scriptlets to install sbcl.info-1 and sbcl.info-2 agains
- install package into old %%{_libdir}/%%{name} place

* Thu Jan 12 2012 kamil <kamil> 1.0.55-0.mga2
+ Revision: 195227
- add missing texlive to BR
- set PREFIX variable (location where the package is working) to %%{_prefix}
- rewrite installation of .info documentation
- new list of files
- drop binary files of sbcl - used previously for bootstrap
- completely rewrite .spec file, inspired by openSUSE one
- make a temporarily initial .spec
  o temporarily disable threating maintance
  o temporarily disable patches
  o make bootstrap with clisp
  o disable post,pre,postup
- new version 1.0.55
- removed %%clean section, %%defattr, cleaning in %%install
+ tv <tv>
- fix bootstrap directory on x86_64
- fix typo in bootstrap macro name on x86_64
- add missing tarballs for bootstrap build
- bootstrap build
- imported package sbcl


* Mon Apr 11 2011 Paulo Andrade <pcpa@mandriva.com.br> 1.0.47-1mdv2011.0
+ Revision: 652674
- Update to sbcl 1.0.47

* Sat Mar 05 2011 Funda Wang <fwang@mandriva.org> 1.0.46-1
+ Revision: 642157
- New version 1.0.4on 6

* Sat Mar 05 2011 Funda Wang <fwang@mandriva.org> 1.0.45-5
+ Revision: 642116
- rebuild to obsolete old packages

* Mon Feb 07 2011 Paulo Andrade <pcpa@mandriva.com.br> 1.0.45-3
+ Revision: 636712
- Correct rpm script for istall/remove of info files

* Wed Feb 02 2011 Paulo Andrade <pcpa@mandriva.com.br> 1.0.45-2
+ Revision: 635347
- Rediff patch1 and remove logic to rename a very long named file

* Thu Jan 27 2011 Shlomi Fish <shlomif@mandriva.org> 1.0.45-1
+ Revision: 633274
- Upgrade to 1.0.45

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Update to version 1.0.40

* Mon Apr 19 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.37-1mdv2010.1
+ Revision: 536788
- update to new version 1.0.37

* Wed Mar 03 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.36-1mdv2010.1
+ Revision: 513976
- Update to new version 1.0.36

* Fri Feb 05 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.35-1mdv2010.1
+ Revision: 501257
- update to new version 1.0.35

* Fri Jan 01 2010 Frederik Himpe <fhimpe@mandriva.org> 1.0.34-1mdv2010.1
+ Revision: 484862
- update to new version 1.0.34

* Sat Nov 28 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.33-1mdv2010.1
+ Revision: 470717
- update to new version 1.0.33

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.32-1mdv2010.1
+ Revision: 462185
- update to new version 1.0.32

* Sat Aug 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.31-1mdv2010.0
+ Revision: 422325
- update to new version 1.0.31

* Wed Jul 29 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.30-1mdv2010.0
+ Revision: 404229
- Update to new version 1.0.30

* Thu Jun 04 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.29-1mdv2010.0
+ Revision: 382863
- Update to new version 1.0.29
- Updated optflags patch from Fedora

* Tue Mar 10 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.26-1mdv2009.1
+ Revision: 353466
- Update to new version 1.0.26

* Thu Feb 05 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.25-1mdv2009.1
+ Revision: 337955
- Update to new version 1.0.25
- New default-sbcl-home patch from Fedora

* Mon Jan 05 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.24-1mdv2009.1
+ Revision: 325080
- Update to new version 1.0.24

* Fri Dec 05 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.23-1mdv2009.1
+ Revision: 310915
- update to new version 1.0.23

* Fri Oct 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.22-1mdv2009.1
+ Revision: 299035
- update to new version 1.0.22

* Sat Oct 11 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.21-1mdv2009.1
+ Revision: 291698
- update to new version 1.0.21

* Tue Sep 02 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.20-1mdv2009.0
+ Revision: 279327
- Update to new version 1.0.20

* Tue Sep 02 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.19-3mdv2009.0
+ Revision: 279242
- Really enable multi-threading now by fixing two typos

* Sun Aug 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.19-2mdv2009.0
+ Revision: 277887
- Now that sbcl is bootstrapped in Mandriva, build with the sbcl rpm
  package as BuildRequires.
- Remove the binary source packages from the SRPM
- Don't compile with -fomit-frame-pointer, it's needed for debugging

* Sun Aug 31 2008 Frederik Himpe <fhimpe@mandriva.org> 1.0.19-1mdv2009.0
+ Revision: 277842
- import sbcl


